/**
 * \file plot.cpp
 * \date November 23, 2011
 * \author Edlira Nano
 */

#include "plot_aligned.h"
#include <qwt_legend.h>
#include <qwt_symbol.h>
#include <qwt_data.h>

PlotAligned::PlotAligned(QWidget *parent) :
		QwtPlot(parent) {

	setAutoReplot(false);

	setTitle("");

	// legend
	QwtLegend * legend = new QwtLegend;
	insertLegend(legend, QwtPlot::BottomLegend);

	setAxisTitle(QwtPlot::xBottom, "Retention time (s)");
	setAxisTitle(QwtPlot::yLeft, "Delta RT (s)");
	// enable zooming
	_zoomer = 0;
	
	_p_curve_deltart = new QwtPlotCurve("Aligned RT");
	_p_curve_ms2 = new QwtPlotCurve("Common identification");
}

PlotAligned::~PlotAligned() {
	this->clear();
	if (_zoomer != 0) {
		delete _zoomer;
		_zoomer = 0;
	}
}

void PlotAligned::viewAlignedMsRun(const Msrun * msrun) {
	qDebug() << "View MsRun aligned";
	const std::vector<mcq_double> originalRt =
			msrun->getOriginalRetentionTimes();
	const std::vector<mcq_double> alignedRt = msrun->getAlignedRetentionTimes();
	if (originalRt.size() == alignedRt.size()) {
		std::vector<mcq_double>::const_iterator itOriginal = originalRt.begin();
		std::vector<mcq_double>::const_iterator itAligned = alignedRt.begin();
		//QwtPlotCurve * curve = new QwtPlotCurve("Aligned RT");
		_p_curve_deltart->setStyle(QwtPlotCurve::Lines);
		_p_curve_deltart->setRenderHint(QwtPlotItem::RenderAntialiased);
		_p_curve_deltart->setPen(QColor(Qt::blue));
		//_alignedPlots.push_back(curve);

		unsigned int plotsize(alignedRt.size());
		mcq_double x1[plotsize], y1[plotsize];
		int i = 0;
		for (; itOriginal != originalRt.end(); ++itOriginal, ++itAligned) {
			y1[i] = (*itOriginal) - (*itAligned);
			x1[i] = (*itOriginal);
			i++;
		}
		_p_curve_deltart->setData(x1, y1, plotsize);

		_p_curve_deltart->attach(this);

		this->setTitle(
				tr("Alignment of '%1'").arg(
						msrun->getXmlFileInfo().fileName()));
		this->replot();
		initZoomer();
	}
}

void PlotAligned::viewAlignedMS2Peaks(const MonitorAlignmentPlot * monitorAlignment) {
	if(monitorAlignment==0)
		return;

	qDebug() << "View Ms2 point";
	//QwtPlotCurve * curve = new QwtPlotCurve("Common identification");
	_p_curve_ms2->setStyle(QwtPlotCurve::Dots);
	_p_curve_ms2->setRenderHint(QwtPlotItem::RenderAntialiased);
	const QwtSymbol symbol(QwtSymbol::Star1, QColor(Qt::black), QColor(Qt::black),
			QSize(9, 9));
	_p_curve_ms2->setSymbol(symbol);
	//_alignedPlots.push_back(curve);

	const std::map<mcq_double,mcq_double>& mapDeltaPeaks =	monitorAlignment->getMs2CommonPeak();
	
	
	
	_msms_data.resize(0);
	//unsigned int plotsize(mapDeltaPeaks.size());
	//mcq_double x1[plotsize], y1[plotsize];
	std::map<mcq_double,mcq_double>::const_iterator it;
	//int i = 0;
	for (it = mapDeltaPeaks.begin(); it != mapDeltaPeaks.end(); ++it) {
		QwtDoublePoint one_point;
		one_point.setX(it->first);
		one_point.setY(it->second);
		_msms_data.push_back(one_point);
		//y1[i] = it->second;
		//x1[i] =  it->first;
		//i++;
	}
	_p_curve_ms2->setData(_msms_data);

	_p_curve_ms2->attach(this);
	this->replot();
	initZoomer();
}

void PlotAligned::clear() {
	qDebug() << "PlotAligned::clear() begin";
	/*
	if (_msms_data.size() > 0) {
		const QwtSymbol symbol(QwtSymbol::Star1, QColor(Qt::white), QColor(Qt::white),
			QSize(9, 9));
		_p_curve_ms2->setSymbol(symbol);
		//QwtData data(_p_curve_ms2->data());
		//QwtData * p_data = _p_curve_ms2->data().copy();
		_p_curve_ms2->setData(_msms_data);
		replot();
	}*/
	
	_p_curve_ms2->setData(QwtArray<QwtDoublePoint>());
	_p_curve_deltart->setData(QwtArray<QwtDoublePoint>());
	_p_curve_ms2->detach();
	_p_curve_deltart->detach();
	

	setAxisAutoScale(QwtPlot::xBottom);
	setAxisAutoScale(QwtPlot::yLeft);
	this->setTitle("");
	_msms_data.resize(0);
	replot();
	initZoomer();

	qDebug() << "PlotAligned::clear() end";
}

void PlotAligned::clearPlot() {
	this->clear();
}


void PlotAligned::initZoomer() {
	// LeftButton for the zooming
	// MidButton for the panning
	// RightButton: zoom out by 1
	// Ctrl+RighButton: zoom out to full size

	if (_zoomer != 0)
		delete _zoomer;

	_zoomer = new QwtPlotZoomer(canvas());
	_zoomer->setResizeMode(QwtPicker::KeepSize);
	_zoomer->setTrackerMode(QwtPicker::AlwaysOn);
	_zoomer->setMousePattern(QwtEventPattern::MouseSelect2, Qt::RightButton,
			Qt::ControlModifier);
	_zoomer->setMousePattern(QwtEventPattern::MouseSelect3, Qt::RightButton);

	const QColor c(Qt::darkBlue);
	_zoomer->setRubberBandPen(c);
	_zoomer->setTrackerPen(c);

}