/*
    MassChroQ : Mass Chromatogram Quantification
    Copyright (C) 2013  Olivier Langella <Olivier.Langella@moulon.inra.fr>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "monitorbridge.h"
#include "../xic/xic_max.h"


MonitorBridge::MonitorBridge() {
    _p_xic = 0;
}

MonitorBridge::~MonitorBridge() {
    if (_p_xic != 0) {
        delete (_p_xic);
    }
}

void MonitorBridge::setCurrentSearchItem(QuantiItemBase * quanti_item) {
    _p_currentSearchItem = quanti_item;
}

void MonitorBridge::setXic(const xicBase * xic) {
    _p_xic = new xicMax(*xic);
}
void MonitorBridge::setAllPeaks(const std::vector<xicPeak *> * p_v_peak_list) {
    //copy vector in _all_peak_list
    qDebug() << "MonitorBridge::setAllPeaks begin";
    std::vector<xicPeak *>::const_iterator it_p_v_peak_list;
    
    for (it_p_v_peak_list = p_v_peak_list->begin(); it_p_v_peak_list != p_v_peak_list->end(); ++it_p_v_peak_list) {
        // qDebug() << it_p_v_peak_list->fisrt;
        _all_peak_list.push_back(new xicPeak(**it_p_v_peak_list));
    }
   qDebug() << "MonitorBridge::setAllPeaks end";
}

void MonitorBridge::setMatchedPeaks(const std::vector<xicPeak *> * p_v_peak_list) {
    qDebug() << "MonitorBridge::setMatchedPeaks begin";
    std::vector<xicPeak *>::const_iterator it_p_v_peak_list;
    for (it_p_v_peak_list = p_v_peak_list->begin(); it_p_v_peak_list != p_v_peak_list->end(); ++it_p_v_peak_list) {
        // qDebug() << it_p_v_peak_list->fisrt;
        _matched_peak_list.push_back(new xicPeak(**it_p_v_peak_list));
    }
    qDebug() << "MonitorBridge::setMatchedPeaks end";
}

void MonitorBridge::setEndCurrentSearchItem() {
}

void MonitorBridge::reportXicOnMonitor(MonitorBase * monitor) const {

    monitor->setCurrentSearchItem(_p_currentSearchItem);
    monitor->setXic(_p_xic);
    monitor->setAllPeaks(&_all_peak_list);
    monitor->setMatchedPeaks(&_matched_peak_list);
    monitor->setEndCurrentSearchItem();


}
