/*
    MassChroQ : Mass Chromatogram Quantification
    Copyright (C) 2013  Olivier Langella <Olivier.Langella@moulon.inra.fr>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <QEventLoop>

#include "quantificatorloop.h"
#include "../consoleout.h"

QuantificatorLoop::QuantificatorLoop(std::vector<QuantiItemBase *> * quanti_items, MonitorBase * p_ext_monitor, const Msrun * p_msrun, const mcq_xic_type & xic_type, const std::vector<const FilterBase *> & xic_filters,const PeakExtractor * p_peak_extractor, const PeakMatcher * peak_matcher, int cpu_number)
{
    qDebug() << " QuantificatorLoop::QuantificatorLoop begin " ;
    _quanti_items = quanti_items;
    //using the Qthread model described here :
    //http://mayaposch.wordpress.com/2011/11/01/how-to-really-truly-use-qthreads-the-full-explanation/
    for (int i=0; i < cpu_number; i++) {
        qDebug() << " QuantificatorLoop::QuantificatorLoop cpu " << i;
        _v_slots.push_back(new QuantificatorLoopSlot(*this, p_ext_monitor, p_msrun, xic_type,xic_filters,p_peak_extractor, peak_matcher));
    }
    _it_quanti_item = _quanti_items->begin();
    _slotFinished = 0;
    _count_xic = 0;
    _quanti_items_size = _quanti_items->size();
    
    _phrase = "MassChroQ-eXtract-Ion-Current";
    _count=0;
    _count_phrase = 0;
}

QuantificatorLoop::~QuantificatorLoop()
{

}

void QuantificatorLoop::loop() {
    for (uint i=0; i < _v_slots.size(); i++) {
        qDebug() << " void QuantificatorLoop::loop() " << i;
        _v_slots[i]->kickStartXicQuantification(getNextQuantiItem());
    }


    qDebug() << "loop started";
    QEventLoop loop;
    QObject::connect(this, SIGNAL(quitLoop()), &loop, SLOT(quit()), Qt::QueuedConnection);
    loop.exec();
    qDebug() << "loop finished";
    /*
    while (slotFinished < _v_slots.size()) {
    	//qDebug() << " void QuantificatorLoop::loop() waiting " << slotFinished;
    	sleep(100);
    }
    */
}

QuantiItemBase * QuantificatorLoop::getNextQuantiItem() {
    qDebug() << " QuantificatorLoop::getNextQuantiItem() begin";
    if (_count_xic == 0) {
        _count_xic++;
    }
    else {
        this->_it_quanti_item++;
        _count_xic++;


    }

    //Print advance of quantification
    if (_count == 100) {
        _count=0;
        if(_count_phrase==0) {
            mcqout() <<"\t";
        }
        if (_count_phrase<_phrase.size()) {
            mcqout() << _phrase.at(_count_phrase);
            mcqout().flush();
            _count_phrase++;
        } else {
            mcqout() << " " << _count_xic << "/" << _quanti_items_size<<endl;
            mcqout().flush();
            _count_phrase=0;
        }
    }

    if (_count_xic > _quanti_items_size) {
        _slotFinished++;

        if (_slotFinished >= _v_slots.size()) {
            qDebug() << " QuantificatorLoop::getNextQuantiItem()  quitLoop " << _slotFinished;
            emit quitLoop();
        }
        qDebug() << " QuantificatorLoop::getNextQuantiItem() " << _slotFinished;
        return NULL;
    }
    /*
    if (this->_it_quanti_item == _quanti_items->end()) {
    	_slotFinished++;

    	if (_slotFinished >= _v_slots.size()) {
    		qDebug() << " QuantificatorLoop::getNextQuantiItem()  quitLoop " << _slotFinished;
    		emit quitLoop();
    	}
    	qDebug() << " QuantificatorLoop::getNextQuantiItem() " << _slotFinished;
    	return NULL;
    }*/
    qDebug() << " QuantificatorLoop::getNextQuantiItem() end";
    return *_it_quanti_item;
}

