/*
    MassChroQ : Mass Chromatogram Quantification
    Copyright (C) 2013  Olivier Langella <Olivier.Langella@moulon.inra.fr>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#include "quantificatorloopslot.h"
#include "quantificatorloopworker.h"
#include "quantificatorloop.h"

#include <QThread>

QuantificatorLoopSlot::QuantificatorLoopSlot(QuantificatorLoop & quantLoop, MonitorBase * p_ext_monitor, const Msrun * p_msrun, const mcq_xic_type & xic_type, const std::vector<const FilterBase *> & xic_filters, const PeakExtractor * p_peak_extractor, const PeakMatcher * peak_matcher)
    :_xic_type(xic_type),_xic_filters(xic_filters),   _quantLoop(quantLoop)
{
    qDebug() << "QuantificatorLoopSlot::QuantificatorLoopSlot";
    _p_msrun =p_msrun;
    _p_ext_monitor =p_ext_monitor;
    _p_peak_matcher = peak_matcher;
    _p_peak_extractor = p_peak_extractor;
    _reportingXic.release();
    //_p_peak_matcher = new PeakMatcher(*peak_matcher);
    // _p_peak_extractor = new PeakExtractor(*p_peak_extractor);
    //qDebug() << "QuantificatorLoopSlot::QuantificatorLoopSlot _peak_extractor " << _peak_extractor;
}

QuantificatorLoopSlot::~QuantificatorLoopSlot()
{

}

void QuantificatorLoopSlot::kickStartXicQuantification(QuantiItemBase * p_currentSearchItem)
{
    if (p_currentSearchItem != NULL) {
        _p_monitor = new MonitorBridge();
        _p_currentSearchItem = p_currentSearchItem;
        //_p_xic = _p_msrun->extractXic(_xic_type, _p_currentSearchItem);
        QThread* thread = new QThread;
        // QuantificatorLoopWorker* worker = new QuantificatorLoopWorker(_p_xic, _p_currentSearchItem, _p_monitor, _p_msrun, _xic_filters, _p_peak_extractor, _p_peak_matcher);
        QuantificatorLoopWorker* worker = new QuantificatorLoopWorker(&_reportingXic, _xic_type, _p_currentSearchItem, _p_monitor, _p_msrun, _xic_filters, _p_peak_extractor, _p_peak_matcher);
        worker->moveToThread(thread);
        connect(worker, SIGNAL(error(QString)), this, SLOT(errorString(QString)));


        connect(thread, SIGNAL(started()), worker, SLOT(process()));
        connect(worker, SIGNAL(finished()), thread, SLOT(quit()));
        connect(worker, SIGNAL(finished()), worker, SLOT(deleteLater()));
        connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));


        connect(worker, SIGNAL(finished()), this, SLOT(xicFinished()));
        thread->start();
	_p_thread = thread;
    }

}

void QuantificatorLoopSlot::errorString(const QString & error_message) const {
    // QObject::tr("%1 CPUs used").arg(cpu_number)
    throw new mcqError(error_message);
}

void QuantificatorLoopSlot::xicFinished() {

    qDebug() << "QuantificatorLoopSlot::xicFinished()";
    _p_monitor->reportXicOnMonitor(_p_ext_monitor);
    _reportingXic.release();
    delete _p_monitor;
    //delete _p_xic;
    _p_thread->wait();
    //get a new xic to qunatify !!!
    kickStartXicQuantification( _quantLoop.getNextQuantiItem());

}
