/*
    MassChroQ : Mass Chromatogram Quantification
    Copyright (C) 2013  Olivier Langella <Olivier.Langella@moulon.inra.fr>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef QUANTIFICATORLOOPSLOT_H
#define QUANTIFICATORLOOPSLOT_H

#include<QObject>
#include<QSemaphore>
#include "../quanti_items/quantiItemBase.h"
#include "../monitors/monitorbridge.h"
#include "../filters/filter_base.h"
#include "../peak_matching/peakMatcher.h"
#include "../peak/peak_extractor.h"

class QuantificatorLoop;

class QuantificatorLoopSlot: public QObject {
    Q_OBJECT

public:
    QuantificatorLoopSlot(QuantificatorLoop & quantLoop, MonitorBase * p_ext_monitor, const Msrun * p_msrun, const mcq_xic_type & xic_type, const std::vector<const FilterBase *> & xic_filters, const PeakExtractor * p_peak_extractor, const PeakMatcher * peak_matcher);
    virtual ~QuantificatorLoopSlot();

    void kickStartXicQuantification(QuantiItemBase * p_currentSearchItem);
    
    QSemaphore _reportingXic;


private :
    MonitorBridge * _p_monitor;
    QuantiItemBase * _p_currentSearchItem;
    const Msrun * _p_msrun;
    const mcq_xic_type & _xic_type;
    const std::vector<const FilterBase *> & _xic_filters;
    const PeakMatcher * _p_peak_matcher;
    const PeakExtractor * _p_peak_extractor;
    MonitorBase * _p_ext_monitor;
    QuantificatorLoop & _quantLoop;

    //xicBase * _p_xic;
    QThread * _p_thread;


public slots:
    void xicFinished();
    void errorString(const QString & error_message) const;
};

#endif // QUANTIFICATORLOOPSLOT_H

