/*
    MassChroQ : Mass Chromatogram Quantification
    Copyright (C) 2013  Olivier Langella <Olivier.Langella@moulon.inra.fr>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#include "quantificatorloopworker.h"
#include "../xic/xic_base.h"

QuantificatorLoopWorker::QuantificatorLoopWorker(QSemaphore * p_reportingXic, const mcq_xic_type & xic_type,QuantiItemBase * p_currentSearchItem, MonitorBridge * p_monitor, const Msrun * p_msrun, const std::vector<const FilterBase *> & xic_filters, const PeakExtractor * p_peak_extractor, const PeakMatcher * peak_matcher):  _xic_type(xic_type), _xic_filters(xic_filters)
{
    _p_currentSearchItem = p_currentSearchItem;
    _p_monitor = p_monitor;
    _p_msrun =p_msrun;
    _p_peak_matcher = peak_matcher;
    _p_peak_extractor = p_peak_extractor;
    _p_reportingXic= p_reportingXic;
    //_p_xic = current_xic;

}

QuantificatorLoopWorker::~QuantificatorLoopWorker()
{

}

void QuantificatorLoopWorker::process() {
    qDebug() << " QuantificatorLoopWorker::process begin semaphore available " << _p_reportingXic->available();
    try {
        _p_monitor->setCurrentSearchItem(_p_currentSearchItem);

        xicBase * _p_xic = _p_msrun->extractXic(_xic_type, _p_currentSearchItem);

        if (_p_xic == 0)
            qDebug() << "detectAndQuantify null xic ";
        qDebug() << " QuantificatorLoopWorker::process begin 2";

        _p_xic->setMonitor(*_p_monitor);
        _p_monitor->setXic(_p_xic);
        // apply filters to the extracted Xic
        // monitor is passed to Xic class which calls
        // monitor.setFilteredXics() method
        _p_xic->applyFilters(_xic_filters);
        qDebug() << " QuantificatorLoopWorker::process begin 3";

        // extract all peaks from xic
        std::vector<xicPeak *> * all_peaks_list =
            _p_peak_extractor->newAllPeaksList(_p_xic);
        _p_monitor->setAllPeaks(all_peaks_list);
        //delete (current_xic);
        qDebug() << " QuantificatorLoopWorker::process begin 4";

        // match the peaks
        std::vector<xicPeak *> * matched_peak_list =
            _p_peak_matcher->newMatchedPeaks(_p_currentSearchItem, all_peaks_list,
                                             _p_msrun);

        _p_monitor->setMatchedPeaks(matched_peak_list);
        _p_monitor->setEndCurrentSearchItem();
        qDebug() << " QuantificatorLoopWorker::process begin 5";

        qDebug() << " QuantificatorLoopWorker::process finished";

        _p_reportingXic->acquire();
        emit finished();

        _p_reportingXic->acquire();
        _p_reportingXic->release();

        // clean up
        if (matched_peak_list != 0) {
            delete matched_peak_list;
            matched_peak_list = 0;
        }

        delete _p_xic;
    }
    catch (mcqError& errorException)
    {
        // QObject::tr("%1 CPUs used").arg(cpu_number)
        // mcqerr() << "Oops! an error occurred in MassChroQ. Dont Panic :" << endl;
        // mcqerr() << error.qwhat() << endl;
        qDebug() << "QuantificatorLoopWorker::process " << errorException.qwhat();
        emit error(errorException.qwhat());
        // windaube_exit();
        // return 1;
    }

}
