/*
    MassChroQ : Mass Chromatogram Quantification
    Copyright (C) 2013  Olivier Langella <Olivier.Langella@moulon.inra.fr>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef QUANTIFICATIONLOOPWORKER_H
#define QUANTIFICATIONLOOPWORKER_H

#include<QObject>
#include<QSemaphore>

#include "../monitors/monitorbridge.h"
#include "../quanti_items/quantiItemBase.h"
#include "../msrun/msrun.h"
#include "../filters/filter_base.h"
#include "../peak_matching/peakMatcher.h"
#include "../peak/peak_extractor.h"

class QuantificatorLoopWorker: public QObject {
    Q_OBJECT

public:
    QuantificatorLoopWorker(QSemaphore * p_reportingXic, const mcq_xic_type & xic_type,  QuantiItemBase * p_currentSearchItem, MonitorBridge * p_monitor, const Msrun * p_msrun, const std::vector<const FilterBase *> & xic_filters, const PeakExtractor * p_peak_extractor, const PeakMatcher * peak_matcher);
    virtual ~QuantificatorLoopWorker();


private :
    //xicBase * _p_xic;
    const mcq_xic_type & _xic_type;
    QuantiItemBase * _p_currentSearchItem;
    MonitorBridge * _p_monitor;
    const Msrun * _p_msrun;
    const std::vector<const FilterBase *> & _xic_filters;
    const PeakMatcher * _p_peak_matcher;
    const PeakExtractor * _p_peak_extractor;
    QSemaphore * _p_reportingXic;


public slots:
    void process();

signals:
    void finished();
    void error(const QString & err);
};

#endif // QUANTIFICATIONLOOPWORKER_H
